@@ -28,3 +28,13 @@ QString Subject::getXMLDescription()
 
 	return s;
 }
+
+int SubjectsList::compareItems(QPtrCollection::Item item1, QPtrCollection::Item item2)
+{
+	if(((Subject*)item1)->name > ((Subject*)item2)->name)
+		return 1;
+	else if(((Subject*)item1)->name < ((Subject*)item2)->name)
+		return -1;
+	else
+		return 0;
+}
